import * as yup from 'yup'
import GenericField from '@/shared/fields/generic-field'
import moment from 'moment'

export default class DateTimeRangeField extends GenericField {
  forFilterInitialValue(value) {
    return value || []
  }

  forFilterCast() {
    return yup.mixed()
  }

  forFilterPreview(value) {
    if (!value || !value.length) {
      return null
    }

    const start = value[0]
    const end = value.length === 2 && value[1]

    if (!start && !end) {
      return null
    }

    if (start && !end) {
      return `> ${formatDatetime(start)}`
    }

    if (!start && end) {
      return `< ${formatDatetime(end)}`
    }

    return `${formatDatetime(start)} - ${formatDatetime(
      end
    )}`
  }
}

function formatDatetime(value) {
  return value
    ? moment(value).format('YYYY-MM-DD HH:mm')
    : null
}
